@@ -679,7 +679,7 @@ class Chemical:
     @property
     def InChI_key(self):
         """[str] IUPAC International Chemical Identifier shorthand."""
-        self._InChI_key
+        return self._InChI_key
     @InChI_key.setter
     def InChI_key(self, InChI_key):
         self._InChI_key = str(InChI_key)
@@ -687,7 +687,7 @@ class Chemical:
     @property
     def common_name(self):
         """[str] Common name identifier."""
-        self._common_name
+        return self._common_name
     @common_name.setter
     def common_name(self, common_name):
         self._common_name = str(common_name)
@@ -695,7 +695,7 @@ class Chemical:
     @property
     def iupac_name(self):
         """[str] Standard name as defined by IUPAC."""
-        self._iupac_name
+        return self._iupac_name
     @iupac_name.setter
     def iupac_name(self, iupac_name):
         self._iupac_name = str(iupac_name)
@@ -703,7 +703,7 @@ class Chemical:
     @property
     def pubchemid(self):
         """[str] Chemical identifier as defined by PubMed."""
-        self._pubchemid
+        return self._pubchemid
     @pubchemid.setter
     def pubchemid(self, pubchemid):
         self._pubchemid = str(pubchemid)
@@ -973,6 +973,7 @@ class Chemical:
     @Hf.setter
     def Hf(self, Hf):
         self._Hf = float(Hf)
+        if self._formula: self.reset_combustion_data()
     
     @property
     def LHV(self):
@@ -1112,6 +1113,12 @@ class Chemical:
         except:
             pass            
         else:
+            if formula and info.formula and formula != info.formula:
+                raise RuntimeError(f'{self.ID} (CAS: {CAS}) formula from database does not '
+                                   'match with user data')
+            if MW and info.MW and MW != info.MW:
+                raise RuntimeError(f'{self.ID} (CAS: {CAS}) molecular weight from database does not '
+                                   'match with user data')
             smiles = smiles or info.smiles
             InChI = InChI or info.InChI
             InChI_key = InChI_key or info.InChI_key
@@ -1479,9 +1486,9 @@ class Chemical:
     def get_key_property_names(self):
         """Return the attribute names of key properties required to model a process."""
         if not self._locked_state and self._phase_ref != 's':
-            return ('V', 'S', 'H', 'Cn', 'Psat', 'Tb')
+            return ('V', 'S', 'H', 'Cn', 'Psat', 'Tb', 'Hvap')
         else:
-            return ('V', 'S', 'H', 'Cn',)
+            return ('V', 'S', 'H', 'Cn')
 
     def default(self, properties=None):
         """
@@ -1641,6 +1648,7 @@ class Chemical:
                     for i, model_handle in handle:
                         models = getfield(other_handle, i)._models.copy()
                         model_handle._models = models
+        if {'Cn', 'Hvap'}.intersection(names): self.reset_free_energies()
     
     @property
     def locked_state(self):
