@@ -222,6 +222,10 @@ class ThermoModelHandle:
                                                    **kwargs)
         if isinstance(evaluate, ThermoModel):
             model = evaluate
+        elif isinstance(evaluate, ThermoModelHandle):
+            raise ValueError("ThermoModelHandle object cannot be added as a "
+                             "model; only ThermoModel objects, functions, "
+                             "and constants can be added")
         else:
             model = thermo_model(evaluate, Tmin, Tmax, Pmin, Pmax,
                                  name, self._var, **kwargs)
