@@ -4,7 +4,7 @@ Created on Sat Nov 30 21:40:59 2019
 
 @author: yoelr
 """
-from flexsolve import aitken
+import flexsolve as flx
 from ..functional import normalize
 
 __all__ = ('solve_x', 'solve_y')
@@ -15,19 +15,23 @@ def x_iter(x, x_gamma_poyinting, gamma, poyinting, T):
     mask = x < 1e-16
     x[mask] = 1e-16
     denominator = gamma(x, T) * poyinting(x, T)
-    x[mask] = 0
-    try: x = x_gamma_poyinting / denominator
-    except FloatingPointError: pass
-    return x
+    return x_gamma_poyinting / denominator
 
 def solve_x(x_gamma_poyinting, gamma, poyinting, T, x_guess):
     if x_guess is None: x_guess = x_gamma_poyinting
-    return aitken(x_iter, x_guess, 1e-6, args=(x_gamma_poyinting, gamma, poyinting, T))
-
+    args = (x_gamma_poyinting, gamma, poyinting, T)
+    try:
+        x = flx.aitken(x_iter, x_guess, 1e-8, args=args)
+    except flx.SolverError as solver_error:
+        x = flx.fixed_point(x_iter, solver_error.x, 1e-8, args=args)
+    except:
+        x = x_gamma_poyinting
+    return x
+        
 def y_iter(y, y_phi, phi, T, P):
     y = normalize(y)
     return y_phi / phi(y, T, P)
 
 def solve_y(y_phi, phi, T, P, y_guess):
     if y_guess is None: y_guess = y_phi
-    return aitken(y_iter, y_phi, 1e-6, args=(y_phi, phi, T, P))
\ No newline at end of file
+    return flx.aitken(y_iter, y_phi, 1e-8, args=(y_phi, phi, T, P))
\ No newline at end of file
