@@ -4,7 +4,7 @@ Created on Wed Mar 20 18:40:05 2019
 
 @author: yoelr
 """
-from flexsolve import wegstein, IQ_interpolation, aitken, SolverError
+import flexsolve as flx
 from ..utils.decorator_utils import thermo_user
 from . import binary_phase_fraction as binary
 from .dew_point import DewPointCache
@@ -86,9 +86,6 @@ class VLE:
                  '_F_mol_vle', # [float] Total moles in equilibrium.
                  '_dew_point_cache', # [Cache] Retrieves the DewPoint object if arguments are the same.
                  '_bubble_point_cache') # [Cache] Retrieves the BubblePoint object if arguments are the same.
-    
-    solver = staticmethod(IQ_interpolation)
-    itersolver = staticmethod(wegstein)
     T_tol = 0.00001
     P_tol = 0.1
     H_hat_tol = 0.1
@@ -410,17 +407,17 @@ class VLE:
             self._refresh_v(V, y_bubble)
             
             try:
-                P = self.solver(self._V_at_P,
-                                P_bubble, P_dew, 0, 1,
-                                self._P, self._V,
-                                self.P_tol, self.V_tol)
+                P = flx.IQ_interpolation(self._V_at_P,
+                                         P_bubble, P_dew, 0, 1,
+                                         self._P, self._V,
+                                         self.P_tol, self.V_tol)
             except:
                 self._V = V
                 self._v = self._estimate_v(V, y_bubble)
-                P = self.solver(self._V_at_P,
-                                P_bubble, P_dew, 0, 1,
-                                self._P, V,
-                                self.P_tol, self.V_tol)
+                P = flx.IQ_interpolation(self._V_at_P,
+                                         P_bubble, P_dew, 0, 1,
+                                         self._P, V,
+                                         self.P_tol, self.V_tol)
             
             # In case solver cannot reach the vapor fraction because
             # the composition does not converge at values that meets the
@@ -486,14 +483,14 @@ class VLE:
         F_mass = self._F_mass
         self._H_hat = H/F_mass
         try:
-            P = self.solver(self._H_hat_at_P,
+            P = flx.IQ_interpolation(self._H_hat_at_P,
                             P_bubble, P_dew,
                             H_bubble/F_mass, H_dew/F_mass,
                             self._P, self._H_hat,
                             self.P_tol, self.H_hat_tol) 
         except:
             self._v = self._estimate_v(V, y_bubble)
-            P = self.solver(self._H_hat_at_P,
+            P = flx.IQ_interpolation(self._H_hat_at_P,
                             P_bubble, P_dew,
                             H_bubble/F_mass, H_dew/F_mass,
                             self._P, self._H_hat,
@@ -529,13 +526,13 @@ class VLE:
             self._V = V 
             
             try:
-                T = self.solver(self._V_at_T,
+                T = flx.IQ_interpolation(self._V_at_T,
                                 T_bubble, T_dew, 0, 1,
                                 self._T , V,
                                 self.T_tol, self.V_tol)
             except:
                 self._v = self._estimate_v(V, y_bubble)
-                T = self.solver(self._V_at_T,
+                T = flx.IQ_interpolation(self._V_at_T,
                                 T_bubble, T_dew, 0, 1,
                                 self._T , V,
                                 self.T_tol, self.V_tol)
@@ -599,7 +596,8 @@ class VLE:
         
         F_mass = self._F_mass
         self._H_hat = H/F_mass
-        self._T = self._thermal_condition.T = self.solver(self._H_hat_at_T,
+        self._T = self._thermal_condition.T = flx.IQ_interpolation(
+                                           self._H_hat_at_T,
                                            T_bubble, T_dew, 
                                            H_bubble/F_mass, H_dew/F_mass,
                                            self._T , self._H_hat,
@@ -643,13 +641,13 @@ class VLE:
         phi = self._phi(y, T, P)
         Psat_over_P_phi = Psats_over_P / phi
         try:
-            x = self.itersolver(self._x_iter,
-                                self._x, 1e-12,
-                                args=(Psat_over_P_phi,))
-        except SolverError as solver_error:
-            x = aitken(self._x_iter,
-                            solver_error.x, 1e-6,
-                            args=(Psat_over_P_phi,))
+            x = flx.wegstein(self._x_iter,
+                           self._x, 1e-12,
+                           args=(Psat_over_P_phi,))
+        except flx.SolverError as solver_error:
+            x = flx.aitken(self._x_iter,
+                           solver_error.x, 1e-6,
+                           args=(Psat_over_P_phi,))
         self._x = x
         v = self._F_mol_vle * self._V * x * self._Ks     
         return fn.normalize(v)
@@ -666,8 +664,8 @@ class VLE:
         if isinstance(self._phi, IdealFugacityCoefficients):
             self._y = self._y_iter(y, Psats_over_P, T, P)
         else:
-            self._y = self.itersolver(self._y_iter, v/v.sum(), 1e-6,
-                                      args=(Psats_over_P, T, P))
+            self._y = flx.wegstein(self._y_iter, v/v.sum(), 1e-6,
+                                   args=(Psats_over_P, T, P))
         self._v = self._F_mol_vle * self._V * self._y
         return self._v
 
