@@ -171,6 +171,9 @@ for i, CAS in zip(homonuclear_elemental_gases, homonuclear_elemental_singlets_CA
     CAS_by_number[i-1] = CAS
 CAS_by_number = tuple(CAS_by_number)
 
+homonuclear_elemental_gases = frozenset(homonuclear_elemental_gases)
+homonuclear_elemental_singlets_CASs = frozenset(homonuclear_elemental_singlets_CASs)
+
 cids = (783, 23987, 3028194, 5460467, 5462311, 5462310, 222, 962, 14917,
         23935, 5360545, 5462224, 5359268, 5461123, 24404, 402, 313, 23968,
         5462222, 5460341, 23952, 23963, 23990, 23976, 23930, 23925, 104730,
@@ -226,8 +229,6 @@ class PeriodicTable:
     def __contains__(self, key):
         for i in self.all_indexes:
             if key in i: return True
-        if isinstance(key, str) and key.isdigit() and int(key) in self.numerical_index:
-            return True
         return False
 
     def __len__(self):
