@@ -10,9 +10,13 @@ import numpy as np
 from typing import Dict
 
 
-__all__ = ('CASDataReader', 'CASDataSource', 'get_from_retrievers',
-           'MultiCheb1D', 'CAS2int', 'int2CAS', 'to_nums')
-
+__all__ = ('CASDataReader', 
+           'CASDataSource', 
+           'get_from_retrievers',
+           'MultiCheb1D',
+           'CAS2int', 
+           'int2CAS', 
+           'to_nums')
 
 class CASDataReader:
     
