@@ -4,6 +4,7 @@ Created on Wed Dec  5 16:47:33 2018
 
 @author: Yoel Cortes-Pena
 """
+# from warnings import warn
 
 __all__ = ('Registry',)
 
@@ -12,12 +13,6 @@ class Registry:
     def search(self, ID):
         return self.__dict__.get(ID)
     
-    def __setattr__(self, ID, obj):
-        self[ID] = obj
-    
-    def __iter__(self):
-        return iter(self.__dict__.values())
-    
     def __getitem__(self, ID):
         return self.__dict__[ID]
     
@@ -30,6 +25,32 @@ class Registry:
                 'ID may only contain letters, numbers, and/or underscores; '
                 'no special characters or spaces')
         self.__dict__[ID] = obj
+        # dct = self.__dict__
+        # if ID in dct and dct[ID] is not obj:
+        #     warn(RuntimeWarning(f"ID, '{ID}', already registered"))
+        # else:
+        #     dct[ID] = obj
+    
+    def __setattr__(self, ID, obj):
+        self[ID] = obj
+    
+    def discard(self, ID):
+        dct = self.__dict__
+        try: dct[ID].disconnect()
+        except AttributeError: pass
+        del dct[ID]
+    
+    def get_IDs(self):
+        return set(self.__dict__)
+    
+    def to_set(self):
+        return set(self.__dict__.values())
+    
+    def __contains__(self, ID):
+        return ID in self.__dict__
+    
+    def __iter__(self):
+        return iter(self.__dict__.values())
     
     def __repr__(self):
         if self.__dict__:
